## cdist-type__install_config(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__install_config - run cdist config as part of the installation

## 2. DESCRIPTION

This cdist type allows you to run cdist config as part of the installation. It does this by using a custom _remote{copy,exec} prefix which runs cdist config against the /target chroot on the remote host.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

chroot
  where to chroot before running grub-install. Defaults to /target.

## 5. EXAMPLES

    __install_config

    __install_config --chroot /mnt/somewhere

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2011 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).